pub unsafe extern "C" fn JSGlobalContextIsInspectable(
ctx: JSGlobalContextRef,
) -> boolExpand description
@function @abstract Gets whether the context is inspectable in Web Inspector. @param ctx The JSGlobalContext that you want to change the inspectability of. @result Whether the context is inspectable in Web Inspector.