JSGlobalContextSetName

Function JSGlobalContextSetName 

pub unsafe extern "C" fn JSGlobalContextSetName(
    ctx: JSGlobalContextRef,
    name: JSStringRef,
)
@function @abstract Sets the name exposed when inspecting a context. @param ctx The JSGlobalContext that you want to name. @param name The name to set on the context.