ulConfigSetMaxUpdateTime

Function ulConfigSetMaxUpdateTime 

pub unsafe extern "C" fn ulConfigSetMaxUpdateTime(
    config: ULConfig,
    max_update_time: f64,
)
The max amount of time (in seconds) to allow repeating timers to run during each call to Renderer::Update.

The library will attempt to throttle timers if this time budget is exceeded.

(Default = 1.0 / 200.0)