ulConfigSetNumRendererThreads

Function ulConfigSetNumRendererThreads 

pub unsafe extern "C" fn ulConfigSetNumRendererThreads(
    config: ULConfig,
    num_renderer_threads: c_uint,
)
The number of threads to use in the Renderer (for parallel painting on the CPU, etc.).

You can set this to a certain number to limit the number of threads to spawn.

@note \parblock

If this value is 0, the number of threads will be determined at runtime using the following formula:

max(PhysicalProcessorCount() - 1, 1)

\endparblock