ulFireGamepadAxisEvent

Function ulFireGamepadAxisEvent 

pub unsafe extern "C" fn ulFireGamepadAxisEvent(
    renderer: ULRenderer,
    evt: ULGamepadAxisEvent,
)
Fire a gamepad axis event (to be called when an axis value is changed).

@note The gamepad should be connected via a previous call to ulFireGamepadEvent.

@see https://developer.mozilla.org/en-US/docs/Web/API/Gamepad/axes