pub unsafe extern "C" fn ulPlatformSetFontLoader(
font_loader: ULFontLoader,
)Expand description
Set a custom FontLoader implementation.
The library uses this to load all system fonts.
Every operating system has its own library of installed system fonts. The FontLoader interface is used to lookup these fonts and fetch the actual font data (raw TTF/OTF file data) for a given given font description.
You should call this before ulCreateRenderer() or ulCreateApp().
@warning This is required to be defined before calling ulCreateRenderer()
@note ulCreateApp() will use the default platform font loader if you never call this.
@note If you’re not using ulCreateApp(), (eg, using ulCreateRenderer()) you can still use the default platform font loader by calling ulEnablePlatformFontLoader()’ (@see <AppCore/CAPI.h>)