ulViewConfigSetDisplayId

Function ulViewConfigSetDisplayId 

pub unsafe extern "C" fn ulViewConfigSetDisplayId(
    config: ULViewConfig,
    display_id: c_uint,
)
Set a user-generated id of the display (monitor, TV, or screen) that the View will be shown on.

Animations are driven based on the physical refresh rate of the display. Multiple Views can share the same display.

@note This is automatically managed for you when ulCreateApp() is used.

@see ulRefreshDisplay()