ulViewConfigSetInitialDeviceScale

Function ulViewConfigSetInitialDeviceScale 

pub unsafe extern "C" fn ulViewConfigSetInitialDeviceScale(
    config: ULViewConfig,
    initial_device_scale: f64,
)
Set the initial device scale, ie. the amount to scale page units to screen pixels. This should be set to the scaling factor of the device that the View is displayed on. (Default = 1.0)

@note 1.0 is equal to 100% zoom (no scaling), 2.0 is equal to 200% zoom (2x scaling)