pub unsafe extern "C" fn ulViewConfigSetInitialFocus(
config: ULViewConfig,
is_focused: bool,
)Expand description
Set whether or not the View should initially have input focus. (Default = True)
pub unsafe extern "C" fn ulViewConfigSetInitialFocus(
config: ULViewConfig,
is_focused: bool,
)Set whether or not the View should initially have input focus. (Default = True)