Function ul_next_sys::ulViewIsLoading
source · pub unsafe extern "C" fn ulViewIsLoading(view: ULView) -> boolExpand description
Check if the main frame of the page is currrently loading.
pub unsafe extern "C" fn ulViewIsLoading(view: ULView) -> boolCheck if the main frame of the page is currrently loading.