Function ul_next_sys::ulWindowMoveToCenter
source · pub unsafe extern "C" fn ulWindowMoveToCenter(arg1: ULWindow)Expand description
Move the window to the center of the monitor.
pub unsafe extern "C" fn ulWindowMoveToCenter(arg1: ULWindow)Move the window to the center of the monitor.