pub type ULFontLoaderLoad = Option<unsafe extern "C" fn(family: ULString, weight: c_int, italic: bool) -> ULFontFile>;Expand description
Get the actual font file data (TTF/OTF) for a given font description.
@param family Font family name.
@param weight Font weight.
@param italic Whether or not italic is requested.
@return A font file matching the given description (either an on-disk font filepath or an in-memory file buffer). You can return NULL here and the loader will fallback to another font.
Aliased Type
pub enum ULFontLoaderLoad {
None,
Some(unsafe extern "C" fn(*mut C_String, i32, bool) -> *mut C_FontFile),
}