pub unsafe extern "C" fn JSGlobalContextSetInspectable(
ctx: JSGlobalContextRef,
inspectable: bool,
)Expand description
@function @abstract Sets whether the context is inspectable in Web Inspector. Default value is NO. @param ctx The JSGlobalContext that you want to change the inspectability of. @param inspectable YES to allow Web Inspector to connect to the context, otherwise NO.