pub unsafe extern "C" fn ulFireGamepadButtonEvent(
renderer: ULRenderer,
evt: ULGamepadButtonEvent,
)Expand description
Fire a gamepad button event (to be called when a button value is changed).
@note The gamepad should be connected via a previous call to ulFireGamepadEvent.
@see https://developer.mozilla.org/en-US/docs/Web/API/Gamepad/buttons