pub unsafe extern "C" fn ulStartRemoteInspectorServer(
renderer: ULRenderer,
address: *const c_char,
port: c_ushort,
) -> boolExpand description
Start the remote inspector server.
While the remote inspector is active, Views that are loaded into this renderer will be able to be remotely inspected from another Ultralight instance either locally (another app on same machine) or remotely (over the network) by navigating a View to:
\code inspector://
:@return Returns whether the server started successfully or not.